# norns

Simple yaml-based config module.

## Installation

Via pip, for now.

```
$ pip install norns
```

## Usage


## Todo

* Add todo!

## Contributing

Contributions welcome! Send me a pull request or get in [touch](simon.vanheeringen@gmail.com).

## License

This module is licensed under the terms of the [MIT license](https://opensource.org/licenses/MIT).
